@@ -6,10 +6,11 @@ use warnings;
 use Unicode::UTF8 qw(encode_utf8);
 use Test::Shared::Fixture::Wikibase::Datatype::Lexeme::Wikidata::DogCzechNoun;
 use Wikibase::Datatype::Print::Form;
-use Wikibase::Datatype::Print::Utils qw(print_forms);
+use Wikibase::Datatype::Print::Utils qw(defaults print_forms);
 
 my $obj = Test::Shared::Fixture::Wikibase::Datatype::Lexeme::Wikidata::DogCzechNoun->new;
-my @ret = print_forms($obj, {'lang' => 'cs'},
+my $opts_hr = defaults({'lang' => 'cs'});
+my @ret = print_forms($obj, $opts_hr,
         \&Wikibase::Datatype::Print::Form::print);
 
 # Print.
